==> postgis-1.3.3-i586-P1.tgz: usr/share/doc/postgis-1.3.3/PlamoBuild.postgis-1.3.3.sh <==
#!/bin/bash
# PostGIS	(http://postgis.refractions.net/)
VERSION=1.3.3
VER=${VERSION%%.?}
#	BuildScript for Plamo Linux 4.5
#			by Jun Kuwamura <juk@linet.gr.jp> on 2008-11-08
# require:
PGVERSION=8.3.4
POSTGRESQL=postgresql-$PGVERSION
GEOS=geos-3.0.0
PROJ=proj-4.5.0
#
PAC_NAME=postgis-$VERSION
SRC_FILE=${PAC_NAME}.tar.gz
SRC_URI=http://postgis.refractions.net/download/$SRC_FILE


REL=P1
CPU=i586
SYS_NAME="${CPU}-${REL}"

PLAMO=/expo/Build
SRC_DIR=$PLAMO/Archive/dbms/pgsql
PAC_DIR=$PLAMO/Packages/4.5/10_gis/
BUILD_DIR=$PLAMO/postgis
CUSTOM_DIR=$BUILD_DIR/Custom
PAT_FILE=

echo $PAC_DIR
if [ ! -d $PAC_DIR ]; then
  mkdir -p  $PAC_DIR
fi
echo $SRC_DIR/$SRC_FILE
if [ ! -f $SRC_DIR/$SRC_FILE ]; then
  if [ ! -d $SRC_DIR ]; then
    mkdir -p $SRC_DIR
  fi
  ( cd $SRC_DIR; wget $SRC_URI )
fi


umask 022
CWD=`pwd`
WORK=$CWD/work
rm -rf $WORK/*
mkdir -p $WORK
export LANG=C
export LC_ALL=C
export CFLAGS="-O2 -march=$CPU"
export PATH=$PATH:/usr/X11R7/bin


# it must be extracted in postgresql tree under contrib.
rm -f $POSTGRESQL
if [ ! -d ../postgresql/$POSTGRESQL ]; then
  echo "../postgresql/$POSTGRESQL not found.";
  exit;
fi
ln -sf ../postgresql/$POSTGRESQL
cd $POSTGRESQL/contrib/

tar xvfz  $SRC_DIR/$SRC_FILE
cd $PAC_NAME
  PREFIX=/opt/pgsql
  ./configure --prefix=$PREFIX \
      --with-pgsql=$PREFIX/bin/pg_config \
      --datadir=$PREFIX/share/contrib \
      --with-geos=/usr/bin/geos-config \
      --with-proj=/usr \
      || exit 1

 # USE_PROJ=1 PROJ_DIR=/usr USE_GEOS=1 GEOS_DIR=/usr  make
 make install DESTDIR=$WORK
 cd topology
 make install DESTDIR=$WORK
 cd ..
 cd doc
 make install DESTDIR=$WORK
 cd ..
  perl utils/create_undef.pl  lwpostgis.sql $PGVERSION > lwpostgis_undef.sql
  cp lwpostgis_undef.sql $WORK/$PREFIX/share/contrib/

 # regression test
 cd regress/
 chown -R postgres .
 su postgres -c make > regress-make.log
 mv regress-make.log $CUSTOM_DIR
 cd ..

DOC_DIR=usr/share/doc/$PAC_NAME
mkdir -p $WORK/$DOC_DIR || exit 1
cp -p $BUILD_DIR/`basename $0`  \
      COPYING TODO CREDITS NEWS ChangeLog README.postgis \
	$WORK/$DOC_DIR

cp -p $CUSTOM_DIR/regress-make.log $WORK/$DOC_DIR
mv $WORK/$PREFIX/share/{man,doc} $WORK/$PREFIX
chown -R root.root $WORK/$DOC_DIR
chmod -R a+rX $WORK/$DOC_DIR


# make package
cd $WORK
 mkdir install
 cp -p $CUSTOM_DIR/doinst.sh-1.3  install/doinst.sh
 sed -e "s/_VER_/$VER/" \
     -e "s/_PACKAGENAME_/${PAC_NAME}-${SYS_NAME}/" \
     $CUSTOM_DIR/doinst.sh > install/doinst.sh
 cp -p $CUSTOM_DIR/lwpostgis-install.sh opt/pgsql/share/contrib/
 cp -p $CUSTOM_DIR/lwpostgis-uninstall.sh opt/pgsql/share/contrib/
 cp opt/pgsql/share/contrib/lwpostgis_undef.sql $CUSTOM_DIR/undef/lwpostgis_undef.sql-${VERSION}
  chown -R postgres:pgsql opt/pgsql

 rm -f ./opt/pgsql/bin/createdb.postgis
 rm -f ./opt/pgsql/bin/mktemplate_gis
 rm -f ./opt/pgsql/bin/rmtemplate_gis

  tar cvfz ../${PAC_NAME}-${SYS_NAME}.tgz \
    opt/pgsql/{bin,lib,doc}/* opt/pgsql/man/*/* opt/pgsql/share/contrib/* usr/share/doc/${PAC_NAME}/ install/doinst.sh
  mv -v ../${PAC_NAME}-${SYS_NAME}.tgz $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz
  ls -l $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz


#echo "y
#1" | makepkg ${PAC_NAME}.tgz
#mv ${PAC_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz
#echo "$PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz ... done"
cd $CWD

==> postgis-1.3.6-i586-P1.tgz: usr/share/doc/postgis-1.3.6/PlamoBuild.postgis-1.3.6.sh <==
#!/bin/bash
# PostGIS	(http://postgis.refractions.net/)
VERSION=1.3.6
VER=${VERSION%%.?}
#	BuildScript for Plamo Linux 4.6
#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-08-21
# require:
PGVERSION=8.3.7
POSTGRESQL=postgresql-$PGVERSION
GEOS=geos-3.1.1
PROJ=proj-4.6.1
#
PAC_NAME=postgis-$VERSION
SRC_FILE=${PAC_NAME}.tar.gz
SRC_URI=http://postgis.refractions.net/download/$SRC_FILE


REL=P1
CPU=i586
SYS_NAME="${CPU}-${REL}"

PLAMO=/expo/Build
SRC_DIR=$PLAMO/Archive/dbms/pgsql
PAC_DIR=$PLAMO/Packages/4.6/10_gis/
BUILD_DIR=$PLAMO/postgis
CUSTOM_DIR=$BUILD_DIR/Custom
PAT_FILE=

echo $PAC_DIR
if [ ! -d $PAC_DIR ]; then
  mkdir -p  $PAC_DIR
fi
echo $SRC_DIR/$SRC_FILE
if [ ! -f $SRC_DIR/$SRC_FILE ]; then
  if [ ! -d $SRC_DIR ]; then
    mkdir -p $SRC_DIR
  fi
  ( cd $SRC_DIR; wget $SRC_URI )
fi


umask 022
CWD=`pwd`
WORK=$CWD/work
rm -rf $WORK/*
mkdir -p $WORK
export LANG=C
export LC_ALL=C
export CFLAGS="-O2 -march=$CPU"
export PATH=$PATH:/usr/X11R7/bin


# it must be extracted in postgresql tree under contrib.
rm -f $POSTGRESQL
if [ ! -d ../postgresql/$POSTGRESQL ]; then
  echo "../postgresql/$POSTGRESQL not found.";
  exit;
fi
ln -sf ../postgresql/$POSTGRESQL
cd $POSTGRESQL/contrib/

tar xvfz  $SRC_DIR/$SRC_FILE
cd $PAC_NAME
  PREFIX=/opt/pgsql
  ./configure --prefix=$PREFIX \
      --with-pgsql=$PREFIX/bin/pg_config \
      --datadir=$PREFIX/share/contrib \
      --with-geos=/usr/bin/geos-config \
      --with-proj=/usr \
      || exit 1

 # USE_PROJ=1 PROJ_DIR=/usr USE_GEOS=1 GEOS_DIR=/usr  make
 make install DESTDIR=$WORK
 cd topology
 make install DESTDIR=$WORK
 cd ..
 cd doc
 make install DESTDIR=$WORK
 cd ..
  perl utils/create_undef.pl  lwpostgis.sql $PGVERSION > lwpostgis_undef.sql
  cp lwpostgis_undef.sql $WORK/$PREFIX/share/contrib/

 # regression test
 cd regress/
 chown -R postgres .
 su postgres -c make > regress-make.log
 mv regress-make.log $CUSTOM_DIR
 cd ..

DOC_DIR=usr/share/doc/$PAC_NAME
mkdir -p $WORK/$DOC_DIR || exit 1
cp -p $BUILD_DIR/`basename $0`  \
      COPYING TODO CREDITS NEWS ChangeLog README.postgis \
	$WORK/$DOC_DIR

cp -p $CUSTOM_DIR/regress-make.log $WORK/$DOC_DIR
mv $WORK/$PREFIX/share/{man,doc} $WORK/$PREFIX
chown -R root.root $WORK/$DOC_DIR
chmod -R a+rX $WORK/$DOC_DIR


# make package
cd $WORK
 mkdir install
 sed -e "s/_VER_/$VER/" \
     -e "s/_PACKAGENAME_/${PAC_NAME}-${SYS_NAME}/" \
     $CUSTOM_DIR/doinst.sh-1.3 > install/doinst.sh
 cp -p $CUSTOM_DIR/lwpostgis-install.sh opt/pgsql/share/contrib/
 cp -p $CUSTOM_DIR/lwpostgis-upgrade.sh opt/pgsql/share/contrib/
 cp -p $CUSTOM_DIR/lwpostgis-uninstall.sh opt/pgsql/share/contrib/
 cp opt/pgsql/share/contrib/lwpostgis_undef.sql $CUSTOM_DIR/undef/lwpostgis_undef.sql-${VERSION}
  chown -R postgres:pgsql opt/pgsql

 rm -f ./opt/pgsql/bin/createdb.postgis
 rm -f ./opt/pgsql/bin/mktemplate_gis
 rm -f ./opt/pgsql/bin/rmtemplate_gis

  tar cvfz ../${PAC_NAME}-${SYS_NAME}.tgz \
    opt/pgsql/{bin,lib,doc}/* opt/pgsql/man/*/* opt/pgsql/share/contrib/* usr/share/doc/${PAC_NAME}/ install/doinst.sh
  mv -v ../${PAC_NAME}-${SYS_NAME}.tgz $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz
  ls -l $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz


#echo "y
#1" | makepkg ${PAC_NAME}.tgz
#mv ${PAC_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz
#echo "$PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz ... done"
cd $CWD
